"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.callerCallsite = void 0;
var index_1 = require("../index");
var debugtsLogger = (0, index_1.debug)('debugts');
/**
 * See npm callsites
 * @returns
 */
var callsites = function () {
    var _a;
    var _prepareStackTrace = Error.prepareStackTrace;
    Error.prepareStackTrace = function (_, stack) { return stack; };
    var stack = (_a = new Error().stack) === null || _a === void 0 ? void 0 : _a.slice(1);
    Error.prepareStackTrace = _prepareStackTrace;
    return stack;
};
function callerCallsite(_a) {
    var _b = _a === void 0 ? {} : _a, _c = _b.depth, depth = _c === void 0 ? 0 : _c;
    var callers = [];
    var callerFileSet = new Set();
    var msg = 'WARN: You are losing debugging information.';
    var result = {
        scope: undefined,
        file: undefined,
        line: undefined,
        position: undefined,
    };
    try {
        for (var _i = 0, _d = callsites(); _i < _d.length; _i++) {
            var callsite = _d[_i];
            var fileName = callsite.getFileName();
            var hasReceiver = callsite.getTypeName() !== null && fileName !== null;
            if (!callerFileSet.has(fileName)) {
                callerFileSet.add(fileName);
                callers.unshift(callsite);
            }
            if (hasReceiver) {
                result.scope = callers[depth].getFunctionName();
                result.file = callers[depth].getFileName();
                result.line = callers[depth].getLineNumber();
                result.position = callers[depth].getColumnNumber();
                return result;
            }
        }
        return null;
    }
    catch (err) {
        debugtsLogger.extend('getCaller')("".concat(msg, " Reason: Error in parsing stack."), err);
        return null;
        // don't return the partial result, because without the filename, it's pretty meaningless
    }
}
exports.callerCallsite = callerCallsite;
//# sourceMappingURL=callerCallsite.js.map